@@ -9,7 +9,7 @@ class Setup():
     #rute = path.abspath(path.join(''))
     rute0 = site.getsitepackages()
     print("The library is installed in")
-    print(rute + '/KrakenOS)
+    print(rute + '/KrakenOS')
     print("for help see Examples directory")
     print("To change glass catalog modify catalog list in SetupCas.py")
     print("See User_Manual USER_MANUAL_KrakenOS_Provisional.pdf in:" )
